@@ -26,7 +26,8 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s slutade dela mappen \"%2$s\" med dig",
     "Someone unshared folder \"%s\" with you" : "Någon slutade  dela mappen \"%s\" med dig",
     "No file provided for import" : "Inga filer given för importering",
-    "Unsupported file type for import" : "Ogiltig filtyp för import",
+    "Failed to upload file" : "Kunde inte ladda upp filen",
+    "Unsupported file type for import: " : "Ogiltig filtyp för import: ",
     "Bookmarks shared by %s" : "Bokmärken delas av %s",
     "Frequent bookmarks" : "Vanliga bokmärken",
     "Recent bookmarks" : "Senaste bokmärken",
@@ -39,6 +40,8 @@ OC.L10N.register(
     "Takes a link and adds it to your collection of bookmarks." : "Tar en länk och lägger till den i dina bokmärken.",
     "Bookmarks Backups" : "Bokmärken säkerhetskopior",
     "Collect and manage bookmarks, synced with all your devices" : "Samla och hantera bokmärken, synkroniserade med alla dina enheter",
+    "Do you really want to delete this bookmark?" : "Är du säker att du vill ta bort detta bokmärket?",
+    "Link copied to clipboard" : "Länken kopierad till urklipp",
     "Enter new title" : "Ange ny titel",
     "Select bookmark" : "Välj bokmärke",
     "You have never clicked this link" : "Du har aldrig klickat på den här länken",
@@ -51,8 +54,6 @@ OC.L10N.register(
     "Put bookmark into trash bin" : "Lägg bokmärket i papperskorgen",
     "Restore bookmark" : "Återställ bokmärke",
     "Delete bookmark permanently" : "Ta bort bokmärke permanent",
-    "Do you really want to delete this bookmark?" : "Är du säker att du vill ta bort detta bokmärket?",
-    "Link copied to clipboard" : "Länken kopierad till urklipp",
     "Content pending" : "Väntar på innehåll",
     "This content is being downloaded for offline use. Please check back later." : "Detta innehåll laddas ner för offlineanvändning. Vänligen försök igen senare.",
     "Bookmarked {time} ago" : "Sparad för {time} sedan",
@@ -64,19 +65,27 @@ OC.L10N.register(
     "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Bokmärkta länkar kontrolleras regelbundet och de som inte kan nås listas här.",
     "You can share bookmark folders with others. All folders shared with you are listed here." : "Du kan dela bokmärkesmappar med andra. Alla mappar som delas med dig listas här.",
     "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Ett bokmärke kan finnas i flera mappar samtidigt. Om du uppdaterar en, uppdateras alla kopior. Alla dubbletter av bokmärken listas här.",
+    "Selected {folders} folders and {bookmarks} bookmarks" : "Valde {folders} mappar och {bookmarks} bokmärken",
+    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valde %n bokmärke","Valde %n bokmärken"],
+    "_Selected %n folder_::_Selected %n folders_" : ["Valde %n mapp","Valde %n mappar"],
+    "Do you really want to delete these items?" : "Är du säker att du vill ta bort dessa objekt?",
     "Open all selected" : "Öppna alla markerade",
     "Move selection" : "Flytta urval",
     "Edit tags of selection" : "Ändra taggar för urval",
     "Delete selection" : "Ta bort urval",
     "Select all" : "Välj alla",
     "Cancel selection" : "Avbryt markering",
-    "Selected {folders} folders and {bookmarks} bookmarks" : "Valde {folders} mappar och {bookmarks} bokmärken",
-    "Do you really want to delete these items?" : "Är du säker att du vill ta bort dessa objekt?",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valde %n bokmärke","Valde %n bokmärken"],
-    "_Selected %n folder_::_Selected %n folders_" : ["Valde %n mapp","Valde %n mappar"],
+    "Sort by created date" : "Sortera efter skapat datum",
+    "Sort by last modified" : "Sortera efter senast modifierad",
+    "Sort by title" : "Sortera efter titel",
+    "Sort by click count" : "Sortera efter antal klicks",
+    "Sort by manual order" : "Sortera efter manuell ordning",
+    "Sort by URL" : "Sortera efter URL",
+    "RSS feed copied" : "Kopierade RSS flöde",
     "Trash Bin" : "Papperskorg",
     "Go back" : "Gå tillbaks",
     "Share folder" : "Dela mapp",
+    "Open folder details" : "Öppna mappinformation",
     "Select one or more tags" : "Välj en eller flera taggar",
     "New" : "Nytt",
     "New bookmark" : "Nytt bokmärke",
@@ -87,13 +96,6 @@ OC.L10N.register(
     "The RSS feed requires authentication with your Nextcloud credentials" : "RSS-flödet kräver autentisering med dina Nextcloud-uppgifter",
     "Search" : "Sök",
     "Empty trash bin" : "Töm papperskorgen",
-    "Sort by created date" : "Sortera efter skapat datum",
-    "Sort by last modified" : "Sortera efter senast modifierad",
-    "Sort by title" : "Sortera efter titel",
-    "Sort by click count" : "Sortera efter antal klicks",
-    "Sort by manual order" : "Sortera efter manuell ordning",
-    "Sort by URL" : "Sortera efter URL",
-    "RSS feed copied" : "Kopierade RSS flöde",
     "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Lägger till %n bokmärke i ny mapp","Lägger till %n bokmärken i ny mapp"],
     "Enter a link" : "Ange en länk",
     "Enter a title" : "Ange en titel",
@@ -105,6 +107,7 @@ OC.L10N.register(
     "Add a bookmark" : "Lägg till ett bokmärke",
     "Import bookmarks" : "Importera bokmärken",
     "Sync with your browser" : "Synkronisera med din webbläsare",
+    "Do you really want to permanently delete this folder?" : "Vill du verkligen ta bort den här mappen permanent?",
     "Select folder" : "Välj mapp",
     "Enter folder title" : "Ange titel",
     "Shared by {user}" : "Delad av {user}",
@@ -113,7 +116,6 @@ OC.L10N.register(
     "Put folder into trashbin" : "Lägg mappen i papperskorgen",
     "Restore folder" : "Återställ mapp",
     "Delete folder permanently" : "Ta bort mapp permanent",
-    "Do you really want to permanently delete this folder?" : "Vill du verkligen ta bort den här mappen permanent?",
     "Choose folder" : "Välj mapp",
     "Submit" : "Skicka",
     "Cancel" : "Avbryt",
@@ -122,6 +124,7 @@ OC.L10N.register(
     "Importing bookmarks" : "Importerar bokmärken",
     "Moving selection" : "Flyttar urval",
     "Adding selection to folders" : "Lägger till urval i mappar",
+    "Emptying trashbin" : "Tömmer papperskorgen",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Flyttar %n mapp och några bokmärken","Flyttar %n mappar och några bokmärken"],
     "_Moving %n folder_::_Moving %n folders_" : ["Flyttar %n mapp","Flyttar %n mappar"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flyttar %n bokmärke","Flyttar %n bokmärken"],
@@ -136,7 +139,7 @@ OC.L10N.register(
     "Delete" : "Ta bort",
     "Untagged" : "Inte taggad",
     "{used} bookmarks of {available} available" : "{used} bokmärken av {available} tillgängliga",
-    "Settings" : "Inställningar",
+    "Bookmarks Settings" : "Bokmärkesinställningar",
     "No bookmarked files" : "Inga bokmärkta filer",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer som foton eller PDF-filer sparas automatiskt i ditt Nextcloud så att du fortfarande kan hitta dem även när länken går offline.",
     "Nothing found" : "Inget hittades",
@@ -148,6 +151,9 @@ OC.L10N.register(
     "You haven't deleted anything yet." : "Du har inte tagit bort något ännu.",
     "No bookmarks here" : "Inga bokmärken här",
     "Add bookmarks manually or import bookmarks from a HTML file." : "Lägg till bokmärken manuellt eller importera bokmärken från en HTML-fil.",
+    "Archive path" : "Sökväg till arkiv",
+    "Backup path" : "Sökväg till säkerhetskopior",
+    "Please select \"Add to home screen\" in your browser menu" : "Vänligen välj \"Lägg till hemskärm\" i din webbläsarmeny",
     "Bookmarks settings" : "Bokmärkesinställningar",
     "Import/Export" : "Import/Export",
     "Export bookmarks" : "Exportera bokmärken",
@@ -155,6 +161,7 @@ OC.L10N.register(
     "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Bokmärkesappen kan automatiskt arkivera webbinnehållet för länkar du har bokmärkt.",
     "Enable archiving" : "Aktivera arkivering",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "Ange sökvägen till en mapp i dina filer där bokmärkta filer ska lagras.",
+    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "För närvarande har din administratör inaktiverat nätverksåtkomst för den här appen, vilket är anledningen till att automatisk arkivering är inaktiverad för tillfället.",
     "Auto-Backup" : "Automatisk säkerhetskopiering",
     "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Bokmärkesappen kan automatiskt säkerhetskopiera dina bokmärken dagligen för att förhindra dataförlust när du synkroniserar bokmärken mellan enheter.",
     "Enable backups" : "Aktivera säkerhetskopiering",
@@ -170,9 +177,7 @@ OC.L10N.register(
     "Need help?" : "Behövs hjälp?",
     "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Om du har problem med denna bokmärkesapp eller har en idé om vad som kan förbättras, tveka inte att höra av dig genom att klicka här.",
     "Support this project" : "Stöd detta projekt",
-    "Archive path" : "Sökväg till arkiv",
-    "Backup path" : "Sökväg till säkerhetskopior",
-    "Please select \"Add to home screen\" in your browser menu" : "Vänligen välj \"Lägg till hemskärm\" i din webbläsarmeny",
+    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Mitt arbete med den här bokmärkesappen drivs av en frivillig prenumerationsmodell. Om du tycker att det jag gör är värt besväret skulle jag bli glad om du kunde stödja mitt arbete. Överväg också att ge appen en recension i Nextclouds appbutik. Tack 💙 ",
     "(Empty title)" : "(Tom titel)",
     "Title" : "Titel",
     "Link" : "Länk",
@@ -185,8 +190,7 @@ OC.L10N.register(
     "Archived file" : "Arkiverad fil",
     "Download file" : "Hämta fil",
     "Open file location" : "Öppna filsökväg",
-    "Created {time} ago" : "Skapad för {time} sedan",
-    "Created on {date}" : "Skapades {date}",
+    "Link copied" : "Länk kopierad",
     "Owner" : "Ägare",
     "Sharing" : "Delning",
     "Select a user or group" : "Välj en användare eller grupp",
@@ -200,7 +204,8 @@ OC.L10N.register(
     "Allow editing" : "Tillåt redigering",
     "Allow resharing" : "Tillåt vidaredelning",
     "Remove share" : "Ta bort delning",
-    "Link copied" : "Länk kopierad",
+    "Failed to save settings" : "Kunde inte spara inställningarna",
+    "Failed to load settings" : "Kunde inte läsa in inställningar",
     "Privacy" : "Integritet",
     "The app will try to access web pages that you add to automatically add information about them." : "Appen kommer försöka komma åt webbsidor som du lägger till för att automatiskt lägga till information om dem.",
     "Enable accessing and collecting information from the web pages you add" : "Aktivera åtkomst till och samla information från webbsidorna du lägger till",
@@ -223,8 +228,6 @@ OC.L10N.register(
     "Pageres CLI" : "Pageres CLI",
     "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Installera Pageres CLI av Sindre Sorhus på din server så hittar Bokmärken det. Du kan fortfarande lägga till ytterligare ENV-variabler som ska matas till Pageres, t.ex. som anges i platshållaren:",
     "Pageres ENV variables" : "Pageres ENV-variabler",
-    "Failed to save settings" : "Kunde inte spara inställningarna",
-    "Failed to load settings" : "Kunde inte läsa in inställningar",
     "This URL is already bookmarked! Overwrite?" : "Den här webbadressen är redan bokmärkt! Skriva över?",
     "Enter bookmark title" : "Ange titel",
     "Enter bookmark URL" : "Ange bokmärkets webbadress",
@@ -233,6 +236,7 @@ OC.L10N.register(
     "Save" : "Spara",
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Nätverkstillgång är inaktiv som standard. Gå till administratör-inställningarna för bokmärkesappen för att tillåta hämtning av förhandsvisningar och ikoner.",
     "What's new?" : "Vad är nytt?",
+    "Leave a rating on the Nextcloud App Store" : "Lämna ett omdöme på Nextcloud App Store",
     "What" : "Vad",
     "Failed to count unavailable bookmarks" : "Det gick inte att räkna otillgängliga bokmärken",
     "Failed to count archived bookmarks" : "Det gick inte att räkna arkiverade bokmärken",
