@@ -40,7 +40,9 @@ OC.L10N.register(
     "Takes a link and adds it to your collection of bookmarks." : "將連結添加到您的書籤收藏。",
     "Bookmarks Backups" : "書籤備份",
     "Collect and manage bookmarks, synced with all your devices" : "收集和管理書籤．並與所有裝置同步",
-    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users and via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 將書籤分類整理到資料夾中\n- 🏷 新增標籤及個人筆記\n- ☠ 找出失效連結及重複項目\n- 📲 與所有瀏覽器及裝置同步\n- 📔 儲存連結的已存檔版本,以防連結停止發佈\n- 🔍 對網站內容進行全文搜索\n- 👪 與其他使用者分享書籤,並提供公開連結\n- ⚛ 為您的書籤集合產生 RSS 訂閱源\n- 📈 統計您存取各個連結的頻率\n- 🔒 自動備份您的書籤集合\n- 💼 內建儀表板小組件以顯示常用及最近的連結\n\n技術要求:\n- PHP 擴充套件:\n- intl: *\n- mbstring: *\n- 使用 MySQL 時，需使用至少 v8.0 版本",
+    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 將書籤分類整理到資料夾中\n- 🏷 添加標籤和個人註解\n- ☠ 找出失效連結及重複項目\n- 📲 與所有瀏覽器及裝置同步\n- 📔 存儲連結已封的存版本，以防它們被刪除\n- 🔍 對網站內容進行全文搜索\n- 👪 與其他用戶、群組和團隊分享書籤，並提供公開連結\n- ⚛ 為您的書籤集合產生 RSS 訂閱源\n- 📈 統計您存取各個連結的頻率\n- 🔒 自動備份您的書籤集合\n- 💼 內建儀表板小組件以顯示常用及最近的連結\n\n技術要求:\n - PHP 擴充套件:\n   - intl: *\n   - mbstring: *\n - 使用 MySQL 時，需使用至少 v8.0 版本",
+    "Do you really want to delete this bookmark?" : "您確定要刪除此書籤嗎？",
+    "Link copied to clipboard" : "已複製連結至剪貼板",
     "Enter new title" : "輸入新的標題",
     "Select bookmark" : "選擇書籤",
     "You have never clicked this link" : "您從未點擊過此連結",
@@ -53,8 +55,6 @@ OC.L10N.register(
     "Put bookmark into trash bin" : "將書籤放到回收桶中",
     "Restore bookmark" : "還原書籤",
     "Delete bookmark permanently" : "永久刪除書籤",
-    "Do you really want to delete this bookmark?" : "您確定要刪除此書籤嗎？",
-    "Link copied to clipboard" : "已複製連結至剪貼板",
     "Content pending" : "內容待定",
     "This content is being downloaded for offline use. Please check back later." : "正在下載此內容以供離線使用。請稍後再檢查。",
     "Bookmarked {time} ago" : "{time} 前加入書籤",
@@ -66,14 +66,23 @@ OC.L10N.register(
     "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "已加入書籤的連結會定期檢查，無法存取的連結就會在此列出。",
     "You can share bookmark folders with others. All folders shared with you are listed here." : "您可以與其他人分享書籤資料夾。此處列出了與您分享的所有資料夾。",
     "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "一個書籤可以同時位於多個文件夾中。 更新它將更新所有副本。 為方便起見，此處列出了所有重複的書籤。",
+    "Selected {folders} folders and {bookmarks} bookmarks" : "所選 {folders} 資料夾 和 {bookmarks} 書籤",
+    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["已選擇 %n 個書籤"],
+    "_Selected %n folder_::_Selected %n folders_" : ["已選擇 %n 個資料夾"],
+    "Do you really want to delete these items?" : "您確定要刪除這些項目嗎？",
     "Open all selected" : "開啟所有選擇對象",
     "Move selection" : "移動選擇",
     "Edit tags of selection" : "編輯所選項目的標籤",
     "Delete selection" : "刪除所選",
     "Select all" : "全選",
     "Cancel selection" : "取消選擇",
-    "Selected {folders} folders and {bookmarks} bookmarks" : "所選 {folders} 資料夾 和 {bookmarks} 書籤",
-    "Do you really want to delete these items?" : "您確定要刪除這些項目嗎？",
+    "Sort by created date" : "按創建日期排序",
+    "Sort by last modified" : "按修改日期排序",
+    "Sort by title" : "按標題排序",
+    "Sort by click count" : "按點擊次數排序",
+    "Sort by manual order" : "手動排序",
+    "Sort by URL" : "依 URL 排序",
+    "RSS feed copied" : "RSS feed 已複製",
     "Trash Bin" : "回收桶",
     "Go back" : "返回",
     "Share folder" : "分享資料夾",
@@ -84,26 +93,23 @@ OC.L10N.register(
     "New folder" : "新增資料夾",
     "Change to grid view" : "切換至網格檢視",
     "Change to list view" : "切換到列表視圖",
-    "Copy RSS Feed of current view" : "複製當前視圖的RSS Feed",
+    "Copy RSS Feed of current view" : "複製目前視圖的RSS Feed",
     "The RSS feed requires authentication with your Nextcloud credentials" : "RSS feed 需要使用您的 Nextcloud 身份驗證進行驗證",
     "Search" : "搜尋",
     "Empty trash bin" : "清空回收桶",
-    "Sort by created date" : "按創建日期排序",
-    "Sort by last modified" : "按修改日期排序",
-    "Sort by title" : "按標題排序",
-    "Sort by click count" : "按點擊次數排序",
-    "Sort by manual order" : "手動排序",
-    "Sort by URL" : "依 URL 排序",
-    "RSS feed copied" : "RSS feed 已複製",
+    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["將 %n 書籤添加到新資料夾"],
     "Enter a link" : "輸入連結",
     "Enter a title" : "輸入標題",
     "No bookmarks found" : "未發現書籤",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} 資料夾和 {bookmarks} 書籤",
+    "_%n bookmark_::_%n bookmarks_" : ["%n 書籤"],
+    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
     "Welcome to Bookmarks" : "歡迎來到 Bookmarks",
     "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "此應用程式允許您管理網絡上您最喜歡的地方的連結。將您的書籤分類到資料夾中，用標籤標記它們並與他人分享！該應用程式將定期檢查您所有連結的空閒時間並顯示不可用的連結。如果您在網絡上添加指向檔案的連結，該檔案將自動下載到您的 Nextcloud Files 中。您還可以導入從其他服務導出的書籤，或直接將所有瀏覽器中的書籤與此應用程式同步。",
     "Add a bookmark" : "新增書籤",
     "Import bookmarks" : "匯入書籤",
     "Sync with your browser" : "與瀏覽器同步",
+    "Do you really want to permanently delete this folder?" : "您真的想要永久刪除此資料夾嗎？",
     "Select folder" : "選擇資料夾",
     "Enter folder title" : "輸入資料夾標題",
     "Shared by {user}" : "由 {user} 分享",
@@ -112,7 +118,6 @@ OC.L10N.register(
     "Put folder into trashbin" : "將資料夾放到回收桶中",
     "Restore folder" : "還原資料夾",
     "Delete folder permanently" : "永久刪除資料夾",
-    "Do you really want to permanently delete this folder?" : "您真的想要永久刪除此資料夾嗎？",
     "Choose folder" : "選擇資料夾",
     "Submit" : "遞交",
     "Cancel" : "取消",
@@ -122,6 +127,9 @@ OC.L10N.register(
     "Moving selection" : "移動選擇",
     "Adding selection to folders" : "將所選項目添加到資料夾",
     "Emptying trashbin" : "清空回收桶",
+    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移動%n資料夾和一些書籤"],
+    "_Moving %n folder_::_Moving %n folders_" : ["移動%n個資料夾"],
+    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移動%n個書籤"],
     "All bookmarks" : "所有書籤",
     "Recent" : "最新",
     "Shared with you" : "與您分享",
@@ -145,6 +153,9 @@ OC.L10N.register(
     "You haven't deleted anything yet." : "您尚未刪除任何東西。",
     "No bookmarks here" : "無書籤",
     "Add bookmarks manually or import bookmarks from a HTML file." : "手動添加書籤或從 HTML 檔案導入書籤。",
+    "Archive path" : "封存路徑",
+    "Backup path" : "備份路徑",
+    "Please select \"Add to home screen\" in your browser menu" : "請在瀏覽器菜單中選擇“添加到主螢幕”",
     "Bookmarks settings" : "書籤設定",
     "Import/Export" : "導入/導出",
     "Export bookmarks" : "導出書籤",
@@ -169,9 +180,6 @@ OC.L10N.register(
     "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "若您在使用此書籤應用程式時遇到問題或有任何關於改進的想法，請隨時按此處與我們聯絡。",
     "Support this project" : "支援此專案",
     "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "我開發呢個「書籤」App 嘅工作係靠自願訂閱模式來維持嘅。如果你覺得我嘅工作有價值，就請支持下我嘅工作。此外，你都可以考慮喺 Nextcloud App 商店裏面，幫呢個 App 寫一個評價。多謝你 💙",
-    "Archive path" : "封存路徑",
-    "Backup path" : "備份路徑",
-    "Please select \"Add to home screen\" in your browser menu" : "請在瀏覽器菜單中選擇“添加到主螢幕”",
     "(Empty title)" : "（空的標題）",
     "Title" : "標題",
     "Link" : "連結",
@@ -184,8 +192,7 @@ OC.L10N.register(
     "Archived file" : "已封存檔案",
     "Download file" : "下載檔案",
     "Open file location" : "開啟檔案位置",
-    "Created {time} ago" : "在 {time} 前創建",
-    "Created on {date}" : "創建於 {date} ",
+    "Link copied" : "連結已複製",
     "Owner" : "擁有者",
     "Sharing" : "分享",
     "Select a user or group" : "選擇用戶或群組",
@@ -199,7 +206,8 @@ OC.L10N.register(
     "Allow editing" : "允許編輯",
     "Allow resharing" : "允許轉貼分享",
     "Remove share" : "移除分享",
-    "Link copied" : "連結已複製",
+    "Failed to save settings" : "設定儲存失敗",
+    "Failed to load settings" : "載入設定失敗",
     "Privacy" : "私隱",
     "The app will try to access web pages that you add to automatically add information about them." : "該應用程式將嘗試存取您新增的網頁以自動新增關於它們的資訊。",
     "Enable accessing and collecting information from the web pages you add" : "從您增加的網頁啟用存取及收集資訊",
@@ -222,8 +230,6 @@ OC.L10N.register(
     "Pageres CLI" : "Pageres CLI",
     "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "只要在您的伺服器上安裝 Sindre Sorhus 開發的 Pageres CLI，書籤應用程式就會找到它。您仍然可以新增額外的 ENV 變數以提供給 pageres，例如在佔位字串中所示：",
     "Pageres ENV variables" : "Pageres ENV 變數",
-    "Failed to save settings" : "設定儲存失敗",
-    "Failed to load settings" : "載入設定失敗",
     "This URL is already bookmarked! Overwrite?" : "此連結已存在，是否複寫？",
     "Enter bookmark title" : "輸入書籤標題",
     "Enter bookmark URL" : "輸入書籤URL",
